@@ -40,7 +40,7 @@ from mo_parsing.whitespaces import Whitespace
 whitespaces.NO_WHITESPACE = Whitespace("").use()
 whitespaces.STANDARD_WHITESPACE = Whitespace().use()
 
-from mo_parsing.infix import LEFT_ASSOC, RIGHT_ASSOC, infix_notation
+from mo_parsing.infix import LEFT_ASSOC, RIGHT_ASSOC, infix_notation, delimited_list
 from mo_parsing.regex import Regex
 from mo_parsing.tokens import *
 
@@ -52,6 +52,7 @@ __all__ = [
     "CharsNotIn",
     "Combine",
     "Dict",
+    "delimited_list",
     "MatchAll",
     "Empty",
     "FollowedBy",
